@@ -1,4 +1,4 @@
-from .basketix_teams_model import BasketixTeamsModel
+from .basketix_teams_model import BasketixTeamsModel, Evaluation, Players
 
 from .nba_players_performances import NbaPlayerPerformanceModel
 from .nba_games import NbaGameModel
@@ -8,3 +8,4 @@ from .nba_game_location import NbaGameLocation
 from .nba_players import NbaPlayerModel, NbaPlayerInjuryInfo, NbaPlayerTeamInfo, NbaPlayerStatInfo, NbaPlayerEvaluationInfo
 
 from .attributes.positions import Position, Position_Enum
+from .attributes.player_id import PlayerId
