@@ -5,6 +5,7 @@ from typing import TypedDict, List
 from typing_extensions import NotRequired
 
 from .attributes.positions import Position
+from .attributes.rotoworld_id import RotoworldId
 
 class NbaPlayerTeamInfo(TypedDict):
     """Sub model for team info for NBA player model"""
@@ -54,6 +55,7 @@ class NbaPlayerModel(TypedDict):
     cost: NotRequired[int]
     costComputationDate: NotRequired[str]
     injury: NotRequired[NbaPlayerInjuryInfo]
+    rotoworldId: NotRequired[RotoworldId]
 
 
 
