@@ -1,6 +1,6 @@
 """NBA games table"""
 
-from ..dynamodb_table import DynamoDBTable
+from .dynamodb_table import DynamoDBTable
 from ..models import NbaGameModel
 
 class NbaGamesTable(DynamoDBTable[NbaGameModel]):
