@@ -1,6 +1,6 @@
 """NBA players table"""
 
-from ..dynamodb_table import DynamoDBTable
+from .dynamodb_table import DynamoDBTable
 from ..models import NbaPlayerModel
 
 class NbaPlayersTable(DynamoDBTable[NbaPlayerModel]):
